[![Build Status](https://img.shields.io/travis/WolfSoftware/phonetic_encoder/master.svg)](https://travis-ci.org/WolfSoftware/phonetic_encoder)
[![Software License](https://img.shields.io/badge/license-MIT-blue.svg)](LICENSE.md)
[![Release](https://img.shields.io/github/release/wolfsoftware/phonetic_encoder.svg)](https://github.com/wolfsoftware/phonetic_encoder/releases/latest)
[![Gem Version](https://badge.fury.io/rb/phonetic_encoder.svg)](https://badge.fury.io/rb/phonetic_encoder)
[![Github commits (since latest release)](https://img.shields.io/github/commits-since/wolfsoftware/phonetic_encoder/latest.svg)](https://github.com/wolfsoftware/phonetic_encoder/commits)
[![GitHub repo size in bytes](https://img.shields.io/github/repo-size/wolfsoftware/phonetic_encoder.svg)](https://github.com/wolfsoftware/phonetic_encoder)
[![GitHub contributors](https://img.shields.io/github/contributors/wolfsoftware/phonetic_encoder.svg)](https://github.com/wolfsoftware/phonetic_encoder)

# Phonetic Encoder

A ruby gem to display the NATO Phonetic name for any given letter. You can also pass custom dictionaries.

## Installation

Add this line to your application's Gemfile:

```ruby
gem 'phonetic_encoder'
```

And then execute:

    $ bundle

Or install it yourself as:

    $ gem install phonetic_encoder

## Usage

### Simple Usage

You can use the default built in dictionary which is NATO.

```ruby
  require 'phonetic_encoder'

  puts PhoneticEncoder::Encoder.encode('abc')

  # or

  puts 'abc'.phonetic_encode
```

### Extended Usage

You can also use the built-in 'sounds' dictionary.

```ruby
  require 'phonetic_encoder'

  puts PhoneticEncoder::Encoder.encode('abc', 'sounds')

  # or

  'abc'.phonetic_encode('sounds')
```

### Advanced Usage

You can define your own dictionary, the below example just does a single item, but you can make the set as large as you need.

```ruby
  require 'phonetic_encoder'

  PhoneticEncoder::Encoder.custom('custom', 'a' => 'apple', 'b' => 'ballon', 'c' => 'cat')

  puts PhoneticEncoder::Encoder.encode('abc', 'custom')

  # or

  'abc'.phonetic_encode('custom')
```

## Development

After checking out the repo, run `bin/setup` to install dependencies. Then, run `rake spec` to run the tests. You can also run `bin/console` for an interactive prompt that will allow you to experiment.

To install this gem onto your local machine, run `bundle exec rake install`. To release a new version, update the version number in `version.rb`, and then run `bundle exec rake release`, which will create a git tag for the version, push git commits and tags, and push the `.gem` file to [rubygems.org](https://rubygems.org).

## Testing

For local testing make sure that you run `bundle exec rspec spec` and then `rake install` to install the gem locally.

## Contributing

Bug reports and pull requests are welcome on GitHub at https://github.com/WolfSoftware/phonetic_encoder. This project is intended to be a safe, welcoming space for collaboration, and contributors are expected to adhere to the [Contributor Covenant](http://contributor-covenant.org) code of conduct.

## License

The gem is available as open source under the terms of the [MIT License](https://opensource.org/licenses/MIT).

## Code of Conduct

Everyone interacting in the phonetic_encoder project’s codebases, issue trackers, chat rooms and mailing lists is expected to follow the [code of conduct](https://github.com/WolfSoftware/phonetic_encoder/blob/master/CODE_OF_CONDUCT.md).
